You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@subversion.apache.org by rh...@apache.org on 2012/05/19 23:20:44 UTC

svn commit: r1340571 - in /subversion/branches/1.7.x-commit-performance: ./ subversion/libsvn_client/commit_util.c subversion/tests/cmdline/lock_tests.py

Author: rhuijben
Date: Sat May 19 21:20:44 2012
New Revision: 1340571

URL: http://svn.apache.org/viewvc?rev=1340571&view=rev
Log:
Merge r1337394 from trunk

Modified:
    subversion/branches/1.7.x-commit-performance/   (props changed)
    subversion/branches/1.7.x-commit-performance/subversion/libsvn_client/commit_util.c
    subversion/branches/1.7.x-commit-performance/subversion/tests/cmdline/lock_tests.py

Propchange: subversion/branches/1.7.x-commit-performance/
------------------------------------------------------------------------------
  Merged /subversion/trunk:r1337394

Modified: subversion/branches/1.7.x-commit-performance/subversion/libsvn_client/commit_util.c
URL: http://svn.apache.org/viewvc/subversion/branches/1.7.x-commit-performance/subversion/libsvn_client/commit_util.c?rev=1340571&r1=1340570&r2=1340571&view=diff
==============================================================================
--- subversion/branches/1.7.x-commit-performance/subversion/libsvn_client/commit_util.c (original)
+++ subversion/branches/1.7.x-commit-performance/subversion/libsvn_client/commit_util.c Sat May 19 21:20:44 2012
@@ -611,7 +611,8 @@ harvest_status_callback(void *status_bat
       case svn_wc_status_none:
         return SVN_NO_ERROR;
       case svn_wc_status_normal:
-        if (!copy_mode && !status->conflicted)
+        if (!copy_mode && !status->conflicted
+            && !(just_locked && status->lock))
           return SVN_NO_ERROR;
         break;
       default:

Modified: subversion/branches/1.7.x-commit-performance/subversion/tests/cmdline/lock_tests.py
URL: http://svn.apache.org/viewvc/subversion/branches/1.7.x-commit-performance/subversion/tests/cmdline/lock_tests.py?rev=1340571&r1=1340570&r2=1340571&view=diff
==============================================================================
--- subversion/branches/1.7.x-commit-performance/subversion/tests/cmdline/lock_tests.py (original)
+++ subversion/branches/1.7.x-commit-performance/subversion/tests/cmdline/lock_tests.py Sat May 19 21:20:44 2012
@@ -159,19 +159,21 @@ def commit_file_unlock(sbox):
   wc_dir = sbox.wc_dir
 
   fname = 'A/mu'
-  file_path = os.path.join(sbox.wc_dir, fname)
+  file_path = sbox.ospath(fname)
 
   # lock fname as wc_author
   svntest.actions.run_and_verify_svn(None, ".*locked by user", [], 'lock',
-                                     '-m', 'some lock comment', file_path)
+                                     '-m', 'some lock comment',
+                                     sbox.ospath(fname),
+                                     sbox.ospath('iota'))
 
   # make a change and commit it, allowing lock to be released
   svntest.main.file_append(file_path, "Tweak!\n")
-  svntest.main.run_svn(None, 'commit', '-m', '',
-                       file_path)
+  svntest.main.run_svn(None, 'commit', '-m', '', wc_dir)
 
   expected_status = svntest.actions.get_virginal_state(wc_dir, 1)
   expected_status.tweak(fname, wc_rev=2)
+  expected_status.tweak('iota', wc_rev=2)
 
   # Make sure the file is unlocked
   svntest.actions.run_and_verify_status(wc_dir, expected_status)
@@ -159,19 +159,21 @@ def commit_file_unlock(sbox):
 
-  # lock fname as wc_author
+  # lock fname and iota as wc_author
   svntest.actions.run_and_verify_svn(None, ".*locked by user", [], 'lock',